@@ -39,7 +39,7 @@ class GeventWebSocketMiddleware(WebSocketMiddleware):
     def __call__(self, environ, start_response):
         handler = self.websocket.routes.get(environ['PATH_INFO'])
 
-        if not handler:
+        if not handler or 'HTTP_SEC_WEBSOCKET_KEY' not in environ:
             return self.wsgi_app(environ, start_response)
 
         # do handshake
